@@ -30,11 +30,11 @@ App::Pod - Quickly show available class methods and documentation.
 
 =head1 VERSION
 
-Version 0.24
+Version 0.25
 
 =cut
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 
 =head1 SYNOPSIS
@@ -533,7 +533,7 @@ sub _abort {
     }
 
     # No wierd class names.
-    if ( $class !~ m{ ^ [-\w_:\\/. ]+ $ }x ) {
+    if ( $class !~ m{ ^ [-~\w_:\\/. ]+ $ }x ) {
         if ( not $self->_opts->{no_error} ) {
             say "";
             say _red( "Invalid class name: $class" );
